@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002, 2003, 2004, 2005, 2007 Free Software Foundation
+ * Copyright (C) 2002, 2003, 2004, 2005, 2007, 2008 Free Software Foundation
  *
  * Author: Nikos Mavrogiannopoulos
  *
@@ -27,8 +27,8 @@
 # include "gnutls_cert.h"
 # include "gnutls_auth.h"
 # include "auth_dh_common.h"
-# include "x509/x509.h"
-# include "openpgp/openpgp.h"
+# include "x509/x509_int.h"
+# include "openpgp/openpgp_int.h"
 
 /* This structure may be complex, but it's the only way to
  * support a server that has multiple certificates
