@@ -42,17 +42,17 @@ bigint_t
 _gnutls_mpi_randomize (bigint_t r, unsigned int bits,
 		       gnutls_rnd_level_t level)
 {
-  int size = 1 + (bits / 8), ret;
+  size_t size = 1 + (bits / 8);
+  int ret;
   int rem, i;
   bigint_t tmp;
   char tmpbuf[512];
   opaque *buf;
-  int buf_release;
+  int buf_release = 0;
 
   if (size < sizeof (tmpbuf))
     {
       buf = tmpbuf;
-      buf_release = 0;
     }
   else
     {
