@@ -21,7 +21,6 @@
  */
 
 #include <int.h>
-#include "errors.h"
 #ifdef STDC_HEADERS
 # include <stdarg.h>
 #endif
@@ -54,16 +53,18 @@ static const libtasn1_error_entry error_algorithms[] = {
   LIBTASN1_ERROR_ENTRY (ASN1_NAME_TOO_LONG),
   LIBTASN1_ERROR_ENTRY (ASN1_ARRAY_ERROR),
   LIBTASN1_ERROR_ENTRY (ASN1_ELEMENT_NOT_EMPTY),
-  {0}
+  {0, 0}
 };
 
 /**
  * asn1_perror - prints a string to stderr with a description of an error
  * @error: is an error returned by a libtasn1 function.
  *
- * This function is like perror(). The only difference is that it
+ * This function is like perror().  The only difference is that it
  * accepts an error returned by a libtasn1 function.
  *
+ * This function replaces libtasn1_perror() in older libtasn1.
+ *
  * Since: 1.6
  **/
 void
@@ -77,9 +78,11 @@ asn1_perror (asn1_retCode error)
  * asn1_strerror - Returns a string with a description of an error
  * @error: is an error returned by a libtasn1 function.
  *
- * This function is similar to strerror(). The only difference is
+ * This function is similar to strerror().  The only difference is
  * that it accepts an error (number) returned by a libtasn1 function.
  *
+ * This function replaces libtasn1_strerror() in older libtasn1.
+ *
  * Returns: Pointer to static zero-terminated string describing error
  *   code.
  *
