@@ -1,7 +1,7 @@
 #ifndef OPENPGP_LOCAL_H
 # define OPENPGP_LOCAL_H
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
